package com.yunzhi.marketing.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.common.StringUtils;
import com.yunzhi.marketing.dto.TaOrgCityDTO;
import com.yunzhi.marketing.entity.TaOrgCity;
import com.yunzhi.marketing.entity.TaSalesBatch;
import com.yunzhi.marketing.mapper.TaOrgCityMapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

@RestController
@RequestMapping("/api")
@Api(value = "立森-开城市接口全部用新的以前的不管他了", tags = "立森-开城市接口全部用新的以前的不管他了")
public class TaOrgCityController extends BaseController {

    @Autowired
    private TaOrgCityMapper taOrgCityMapper;

    @ApiOperation(value = "获取此项目的城市集合", notes = "获取此项目的城市集合")
    @ApiImplicitParams({
            @ApiImplicitParam(dataTypeClass = String.class, paramType = "query", name = "pageNum", value = "第几页"),
            @ApiImplicitParam(dataTypeClass = String.class, paramType = "query", name = "pageSize", value = "一页多少行"),
            @ApiImplicitParam(dataTypeClass = String.class, paramType = "query", name = "parentid", value = "父级id 不传查询所以  100000 查询的是省级机构"),
    })
    @GetMapping(value = "/admin/city/list")
    public ResponseBean adminTdCityList(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                        @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                        @RequestParam(value = "parentid", required = false) String parentid,
                                        HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean<>();
        IPage<TaOrgCity> pg = new Page<>(pageNum, pageSize);
        Integer orgId = getOrgId(request);
        LambdaQueryWrapper<TaOrgCity> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaOrgCity::getOrgId,orgId);
        queryWrapper.eq(TaOrgCity::getStatus,1);
        queryWrapper.eq(!StringUtils.isEmpty(parentid),TaOrgCity::getParentid,parentid);
        IPage<TaOrgCity> taOrgCityIPage = taOrgCityMapper.selectPage(pg, queryWrapper);
        responseBean.addSuccess(taOrgCityIPage);
        return responseBean;
    }

    @ApiOperation(value = "添加此项目的城市", notes = "添加此项目的城市")
    @PostMapping(value = "/admin/city/add")
    public ResponseBean addCity(@RequestBody TaOrgCityDTO taOrgCityDTO, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean<>();
        TaOrgCity taOrgCity = new TaOrgCity();
        BeanUtils.copyProperties(taOrgCityDTO,taOrgCity);
        taOrgCity.setOrgId(getOrgId(request));
        taOrgCity.setStatus(1);
        taOrgCityMapper.insert(taOrgCity);
        responseBean.addSuccess(taOrgCity);
        return responseBean;
    }

    @ApiOperation(value = "删除此项目的城市", notes = "添加此项目的城市")
    @DeleteMapping(value = "/admin/org/city/{id}")
    public ResponseBean deleteCity(@PathVariable Integer id, HttpServletRequest request) {
        return ResponseBean.success(taOrgCityMapper.deleteById(id));
    }
}
